﻿using System;
using System.Windows.Forms;
using org.mbed.RPC;
using System.Diagnostics;
using System.Threading;

namespace mbedRPC.Test
{
    public partial class mbedRCPTest : Form
    {
        DigitalOut led1;        // mbed DigitalOut RPC declaration -> LED1
        DigitalOut led2;        // mbed DigitalOut RPC declaration -> LED2
        mbed mbed;              // the embed itself

        public mbedRCPTest()
        {
            InitializeComponent();
        }

        private void btnExit_Click(object sender, EventArgs e)
        {
            try
            {
                mbed.delete();
                Debug.Print("Complete");
            }
            catch (NullReferenceException ex)
            {
               Debug.Print("No Reference: " + ex.Message);
            }
            this.Close();
        }

        private void mbedRCPTest_Load(object sender, EventArgs e)
        {
            Debug.Print("mbed RPC Hello World");

		    //Create an mbed object for communication over USB (serial)
		    mbed = new SerialRxTxRPC("COM10", 9600);
            //Or over serial: mbed = new SerialRPC("COM10", 9600);
		    //Or later:   mbed = new HTTPRPC("http://192.168.2.2")
		
		    //Create new Digital Outputs on the mbed
		    led1 = new DigitalOut(mbed, mbed.LED1);
		    led2 = new DigitalOut(mbed, mbed.LED2);
        }

        private void flash(int n)
        {
            try
            {
                for (int i = 0; i < n; i++)
                {
                    //Call the DigitalOut objects' methods 
                    led1.write(1);          // on
                    led2.write(0);          // off
                    Thread.Sleep(250);      
                    led1.write(0);          // off
                    led2.write(1);          // on
                    Thread.Sleep(250);
                }
                led2.write(0);        // reset last state - all leds are off now
            }
            catch (NullReferenceException ex)
            {
                Debug.Print("No Reference: " + ex.Message);
            }
        }

        private void btnFlash_Click(object sender, EventArgs e)
        {
            btnFlash.Enabled = false;
            btnExit.Enabled = false;
            btnFlash.Text = "Is Flashing";
            flash(10);
            btnFlash.Text = "Start Flash";
            btnExit.Enabled = true;
            btnFlash.Enabled = true;
        }
    }
}
